@@ -1228,6 +1228,7 @@ class yank(commands.Command):
 		parser.add_argument("--clipboard", "-c", dest="selection", action="store_const", const=cls.SELECTION_CLIPBOARD)
 		parser.add_argument("--no-git", "-n", action="store_true", help=_("Do not replace git placeholders (works also with unstaged and uncommitted changes)"))
 		parser.add_argument("--follow", "-f", action="store_true", help=_("Select a hash id which you want to copy the information for (like with the command `link`)"))
+		parser.add_argument("--braces", "-b", action="store_true", help=_("Wild cards are wrapped in curly braces"))
 		parser.add_argument("--verbose", action="store_true", help=_("Show the command used to copy the information"))
 
 	@classmethod
@@ -1283,10 +1284,15 @@ class yank(commands.Command):
 		else:
 			sorted_placeholders = self.sorted_placeholders
 
+		if args.braces:
+			pattern = r'\{%s\}'
+		else:
+			pattern = r'\b%s\b'
+
 		for human_readable, git_readable in sorted_placeholders:
-			fmt = re.sub(r'\b%s\b' % human_readable, git_readable, fmt)
+			fmt = re.sub(pattern % human_readable, git_readable, fmt)
 		for human_readable, func in self.sorted_placeholders_any:
-			fmt = re.sub(r'\b%s\b' % human_readable, lambda m: getattr(self, func)(hash_id, type_id), fmt)
+			fmt = re.sub(pattern % human_readable, lambda m: getattr(self, func)(hash_id, type_id), fmt)
 
 		if type_id == self.app.TYPE_TAG:
 			cmd = ["git", "for-each-ref", "--format", fmt, "refs/tags/%s" % hash_id]
